from django.apps import AppConfig


class AgentActionsConfig(AppConfig):
    name = "django_agent_actions"
    label = "django_agent_actions"
    verbose_name = "Agent Actions"
    default_auto_field = "django.db.models.BigAutoField"
